<?php
/**
 * @package WW_BRK_Chatbot
 * @version 1.1
 */

/**
 * Plugin Name:  Wasserwacht Bayern - BRK Chatbot Plugin
 * Plugin URI: https://www.minicms.wasserwacht.de/minicms/
 * Version: 1.2
 * Description: Bindet den BRK Henry Chatbot in Wordpress ein.
 * Author: Tobias Meindl <tobias@meindl.dev>
 * Author URI: https://meindl.dev/
 * License: ToDo
 * License URI: https://todo
 */

function wwchatbot_add_settings_page()
{
    add_options_page('WW Chatbot Plugin', 'BRK Wasserwacht - Henry Chatbot Plugin', 'manage_options', 'wwbrk-chatbot-plugin', 'wwchatbot_render_plugin_settings_page');
}

add_action('admin_menu', 'wwchatbot_add_settings_page');

function wwchatbot_render_plugin_settings_page()
{
    ?>
    <h2>BRK Wasserwacht - Henry Chatbot Plugin Einstellungen</h2>
    <form action="options.php" method="post">
        <?php
        settings_fields('wwchatbot_plugin_options');
        do_settings_sections('wwchatbot_plugin'); ?>
        <input name="submit" class="button button-primary" type="submit" value="<?php esc_attr_e('Save'); ?>"/>
    </form>
    <?php
}

function wwchatbot_register_settings()
{
    register_setting('wwchatbot_plugin_options', 'wwchatbot_plugin_options', 'wwchatbot_plugin_options_validate');
    add_settings_section('api_settings', 'Einstellungen', 'wwchatbot_plugin_section_text', 'wwchatbot_plugin');

    add_settings_field('wwchatbot_plugin_setting_api_key', 'Bitte wähle hier Deinen Kreisverband aus:', 'wwchatbot_plugin_setting_api_key', 'wwchatbot_plugin', 'api_settings');
}

add_action('admin_init', 'wwchatbot_register_settings');

function wwchatbot_plugin_options_validate($input)
{
    $newinput['api_key'] = trim($input['api_key']);
    if (!preg_match('/[a-z]+_[a-z]+/i', $newinput['api_key'])) {
        $newinput['api_key'] = '';
    }

    return $newinput;
}

function wwchatbot_plugin_section_text()
{
    echo '<p>Der BRK Chatbot „Henry“ ist ein digitaler Assistent, der ehrenamtlich Interessierten auf Basis von Künstlicher Intelligenz (KI) erste Fragen rund ums Ehrenamt beantworten soll.</p>';
}

function wwchatbot_plugin_setting_api_key()
{
    $options = get_option('wwchatbot_plugin_options');
    $arr = ["brkkvaic_ww" => "Aichach-Friedberg", "brkkvalt_ww" => "Altötting", "brkamb_ww" => "Amberg-Sulzbach", "brkansb_ww" => "Ansbach", "brkasch_ww" => "Aschaffenburg", "brkkva_ww" => "Augsburg-Land", "brkkvags_ww" => "Augsburg-Stadt", "brkkg_ww" => "Bad Kissingen", "brkbtw_ww" => "Bad Tölz-Wolfratshausen", "brkbamb_ww" => "Bamberg", "brkbayr_ww" => "Bayreuth", "brkbgl_ww" => "Berchtesgadener Land", "brkcha_ww" => "Cham", "brkcobu_ww" => "Coburg", "brkdah_ww" => "Dachau", "brkdeg_ww" => "Deggendorf", "brkdill_ww" => "Dillingen", "brkkveber_ww" => "Ebersberg", "brkeich_ww" => "Eichstätt", "brkerdi_ww" => "Erding", "brkerh_ww" => "Erlangen-Höchstadt", "brkkvfo_ww" => "Forchheim", "brkfrei_ww" => "Freising", "brkfrey_ww" => "Freyung-Grafenau", "brkffb_ww" => "Fürstenfeldbruck", "brkfuerth_ww" => "Fürth", "brkgarmisch_ww" => "Garmisch-Partenkirchen", "brkguen_ww" => "Günzburg", "brkhass_ww" => "Haßberge", "brkhof_ww" => "Hof", "brkin_ww" => "Ingolstadt", "brkkvkel_ww" => "Kelheim", "brkkvkt_ww" => "Kitzingen", "brkkrona_ww" => "Kronach", "brkkvll_ww" => "Landsberg", "brkla_ww" => "Landshut", "brklicht_ww" => "Lichtenfels", "brklindau_ww" => "Lindau", "brkmainsp_ww" => "Main-Spessart", "brkmies_ww" => "Miesbach", "brkkvmilt_ww" => "Miltenberg-Obernburg", "brkkvmuehl_ww" => "Mühldorf", "brkmuen_ww" => "München", "brkulm_ww" => "Neu-Ulm", "brknd_ww" => "Neuburg-Schrobenhausen", "brkneum_ww" => "Neumarkt", "brknea_ww" => "Neustadt/Aisch-Bad Windsheim", "brknords_ww" => "Nordschwaben", "brknland_ww" => "Nürnberg Land", "brknuest_ww" => "Nürnberg Stadt", "brkkvoa_ww" => "Oberallgäu", "nrkosta_ww" => "Ostallgäu", "brkpa_ww" => "Passau", "brkpaf_ww" => "Pfaffenhofen", "brkregen_ww" => "Regen", "brkreg_ww" => "Regensburg", "brkrho_ww" => "Rhön-Grabfeld", "brkrosenheim_ww" => "Rosenheim", "brkkvpan_ww" => "Rottal-Inn", "brksad_ww" => "Schwandorf", "brksw_ww" => "Schweinfurt", "brkkvsr_ww" => "Straubing-Bogen", "brksfrank_ww" => "Südfranken", "brktirsch_ww" => "Tirschenreuth", "brkts_ww" => "Traunstein", "brkuallg_ww" => "Unterallgäu", "brkwen_ww" => "Weiden-Neustadt", "brkweil_ww" => "Weilheim", "brkwun_ww" => "Wunsiedel", "brkwue_ww" => "Würzburg"];
    //echo "<input id='wwchatbot_plugin_setting_api_key' name='wwchatbot_plugin_options[api_key]' type='text' value='" . esc_attr($options['api_key']) . "' />";
    echo "<select id='wwchatbot_plugin_setting_api_key' name='wwchatbot_plugin_options[api_key]'>";
    foreach ($arr as $item => $value) {
        if (esc_attr($options['api_key']) === $item) {
            echo '<option value="' . $item . '" selected>' . $value . '</option>';
        } else {
            echo '<option value="' . $item . '">' . $value . '</option>';
        }
    }
    echo "</select>";
}


function append_css()
{
    echo '<style>
      df-messenger {
        --df-messenger-button-titlebar-color: #002d5f;
        --df-messenger-send-icon: #e60005;
        --df-messenger-bot-message: #ffffff;
        --df-messenger-user-message: #ecf6fb;
        --df-messenger-chat-background-color: #fafafa;
      }
    </style>';

}

add_action('wp_head', 'append_css');

function append_js()
{
    $url = plugins_url('/public/df-messenger/index.js', __FILE__);
    $url_fix = plugins_url('/public/dfm-ui-fix.js', __FILE__);
    echo '<script src="' . $url . '"></script><script src="' . $url_fix . '"></script>';

}

add_action('wp_head', 'append_js');

function append_messenger()
{
    $url = plugins_url('/public/brk_bot_icon.svg', __FILE__);
    $options = get_option('wwchatbot_plugin_options');
    if (array_key_exists('api_key', $options) && $options["api_key"] !== "") {
        echo '<df-messenger
      intent="' . $options["api_key"] . '"
      chat-title="Henry"
      agent-id="b5a77b6c-9d57-46a7-b431-e6486917f463"
      language-code="de"
      chat-icon="' . $url . '"
    ></df-messenger>';
    } else {
        echo '<!-- WW Chatbot Plugin: API-Key Missing! -->';
    }

}

add_action('wp_head', 'append_messenger');


/** Always end your PHP files with this closing tag */
?>
